@@ -9,21 +9,21 @@ def get_response(response):
             response = response.text
     return response
 def get_result(response,key='result'):
-    result = get_response(response)
-    if isinstance(result,dict):
-        result = result.get(key,result)
-    return result
+    response = get_response(response)
+    if isinstance(response,dict):
+        result = get_any_value(response,key)
+        return result
+    return response
 def get_all_txns(pair_id):
     transactions = call_solcatcher_db('/api/get_transactions',pair_id)
     return transactions
 def process_logs(transaction):
-    signatures = get_any_value(transaction, 'signatures')
-    for signature in signatures:
-        slot = get_any_value(transaction, 'slot')
-        logs = get_any_value(transaction, 'logMessages')
-        program_id = '6EF8rrecthR5Dkzon8Nwu78hRvfCKubJ14M5uBEwF6P'
-        response = call_solcatcher_ts('process-logs', signature=signature, slot=slot, program_id=program_id, logs=logs)
-    return signatures[0]
+    signature = get_any_value(transaction, 'signatures')[0]
+    slot = get_any_value(transaction, 'slot')
+    logs = get_any_value(transaction, 'logMessages')
+    program_id = '6EF8rrecthR5Dkzon8Nwu78hRvfCKubJ14M5uBEwF6P'
+    response = call_solcatcher_ts('process-logs', signature=signature, slot=slot, program_id=program_id, logs=logs)
+    return signature
 def get_pair(pair_id=None,mint=None,signature=None):
     try:
         raw_pair_data = call_solcatcher_db('/api/get_pair',mint=mint,pair_id=pair_id,signature=signature)
@@ -38,7 +38,7 @@ def get_transactions(pair_id=None,txn_id=None,signature=None,log_id=None):
     except Exception as e:
         input(e)
 def decodeInstructionData(data):
-    response = call_solcatcher_ts('decode-instruction-data', string=data)
+    response = call_solcatcher_ts('decode-instruction-data', string=data,solcatcherSettings={"getResult":True,"getResponse":True})
     decodedData = get_result(response)
     return decodedData
 def upsertPairData(pairData):
